#!/bin/bash

set -e

TARBALL="${1}"
if [[ ${TARBALL} != *util-linux-* ]] ; then
	echo "Please provide a util-linux source tarball."
	exit 1
fi
[[ -f ${TARBALL} ]] || exit 1

P="$(grep -Eo 'util-linux-[[:digit:]]\.[[:digit:]]{2}(\.[[:digit:]]{1,2}|-rc[[:digit:]])' <<< ${TARBALL})"
SRCDIR="$(pwd)"

cleanup() {
	local tdir
	for tdir in ${SRCDIR}/{${P},man} ; do
		if [[ -d "${tdir:-idontexist}" ]] ; then
			rm "${tdir}" -rf
		fi
	done
}

cleanup

tar -xaf ${TARBALL}
cd ${P}
configure_args=(
	--enable-all-programs
	--enable-asciidoctor
	--mandir="/"

	# Keep this in sync with current util-linux ebuilds!!!
	--disable-chfn-chsh
	--disable-login
	--disable-newgrp
	--disable-nologin
	--disable-pylibmount
	--disable-vipw
)
./configure "${configure_args[@]}"
make -j$(nproc) gen-man
make -j$(nproc) DESTDIR="${SRCDIR}/man" install-data
cd -
tar -cJf ${P}-manpages.tar.xz man/man* ${0%*/}

du -h ${P}-manpages.tar.xz
cleanup
